==> rook_users-0.1.0.tar.gz: lib/src/data/server/users_api.dart <==
import 'dart:convert';

import 'package:http/http.dart' as http;
import 'package:rook_users/src/data/server/dto/create_rook_user_request.dart';

import 'api_exception.dart';

/// Helper class to send users requests.
class UsersApi {
  final http.Client _client = http.Client();

  final String _apiUrl;
  final String _clientUUID;
  final String _clientPassword;

  String _auth = '';

  UsersApi({
    required String apiUrl,
    required String clientUUID,
    required String clientPassword,
  })  : _apiUrl = apiUrl,
        _clientUUID = clientUUID,
        _clientPassword = clientPassword;

  String get urlPostFix => '/api/v1';

  String _generateAuthorization() {
    if (_auth.isEmpty) {
      final utf8Auth = utf8.encode('$_clientUUID:$_clientPassword');
      _auth = 'Basic ${base64.encode(utf8Auth)}';
    }

    return _auth;
  }

  /// Sends json string to server.
  ///
  /// This function builds a generic request and decodes the returned bytes.
  ///
  /// Using http package's built in post function will result in 'Content-Type' header being locked to 'application/json; charset=utf-8'.
  Future<bool> _postUserData(Uri uri, String json) async {
    final request = http.Request('POST', uri);
    request.body = json;
    request.headers['Accept'] = 'application/json';
    request.headers['Content-Type'] = 'application/json';
    request.headers['Authorization'] = _generateAuthorization();

    final streamedResponse = await _client.send(request);
    final response = await http.Response.fromStream(streamedResponse);

    if (response.statusCode == 409 || response.statusCode == 201) {
      return true;
    } else {
      throw ApiException(code: response.statusCode, message: response.body);
    }
  }

  /// Registers the user in server.
  ///
  /// [request] - [CreateRookUserRequest] instance.
  Future<bool> createRookUser(CreateRookUserRequest request) async {
    final uri = Uri.https(_apiUrl, '$urlPostFix/create-user');

    return _postUserData(uri, request.toJson());
  }
}

==> rook_users-0.4.1.tar.gz: lib/src/data/server/users_api.dart <==
import 'package:http/http.dart';
import 'package:rook_users/src/data/server/dto/create_rook_user_request.dart';
import 'package:rook_users/src/data/server/helper/get_basic_auth_from_credentials.dart';
import 'package:rook_users/src/data/server/helper/get_error_from_response.dart';

/// Helper class to send users requests.
class UsersApi {
  final Client _client = Client();

  final String _apiUrl;
  final String _clientUUID;
  final String _clientPassword;

  String _auth = '';

  UsersApi({
    required String apiUrl,
    required String clientUUID,
    required String clientPassword,
  })  : _apiUrl = apiUrl,
        _clientUUID = clientUUID,
        _clientPassword = clientPassword;

  String get urlPostFix => '/api/v1';

  String get authorization {
    if (_auth.isEmpty) {
      _auth = getBasicAuthFromCredentials(_clientUUID, _clientPassword);
    }

    return _auth;
  }

  /// Sends json string to server.
  ///
  /// This function builds a generic request and decodes the returned bytes.
  ///
  /// Using http package's built in post function will result in 'Content-Type' header being locked to 'application/json; charset=utf-8'.
  Future<bool> _postUserData(Uri uri, String json) async {
    final request = Request('POST', uri);
    request.body = json;
    request.headers['Accept'] = 'application/json';
    request.headers['Content-Type'] = 'application/json';
    request.headers['Authorization'] = authorization;

    final streamedResponse = await _client.send(request).timeout(tenSeconds);
    final response = await Response.fromStream(streamedResponse);

    if (response.statusCode == 409 || response.statusCode == 201) {
      return true;
    } else {
      throw Exception(getErrorFromResponse(response));
    }
  }

  Future<bool> createRookUser(CreateRookUserRequest request) async {
    final uri = Uri.https(_apiUrl, '$urlPostFix/create-user');

    return _postUserData(uri, request.toJson());
  }
}

const tenSeconds = Duration(seconds: 10);
